@@ -237,8 +237,8 @@ int readServiceInfo(char * name, struct service * service, int honorHide) {
     struct service serv = { 
 	    	    name: NULL, 
 		    levels: -1, 
-		    kPriority: -2, 
-		    sPriority: -2, 
+		    kPriority: -1, 
+		    sPriority: -1, 
 		    desc: NULL, 
 		    startDeps: NULL, 
 		    stopDeps: NULL,
@@ -328,17 +328,15 @@ int readServiceInfo(char * name, struct service * service, int honorHide) {
 		free(bufstart);
 		return 1;
 	    }
-	    if (serv.sPriority == -2 || serv.kPriority == -2) {
-		    if (spri > 99 || kpri > 99 || kpri < 0 || spri < 0) {
-			    if (serv.desc) free(serv.desc);
-			    free(bufstart);
-			    return 1;
-		    }
-		    if (serv.sPriority == -2)
-			    serv.sPriority = spri;
-		    if (serv.kPriority == -2)
-			    serv.kPriority = kpri;
+	    if (spri > 99 || kpri > 99 || kpri < 0 || spri < 0) {
+		    if (serv.desc) free(serv.desc);
+		    free(bufstart);
+		    return 1;
 	    }
+	    if (serv.sPriority == -1)
+			serv.sPriority = spri;
+	    if (serv.kPriority == -1)
+			serv.kPriority = kpri;
 
 	    if (serv.levels == -1) {
 		    if (!strcmp(levelbuf, "-"))
@@ -393,8 +391,6 @@ int readServiceInfo(char * name, struct service * service, int honorHide) {
 		char *t;
 		int numdeps = 0;
 		
-
-		serv.sPriority = -1;
 		start+=15;
 		while (1) {
 			while (*start && isspace(*start) && start < end) start++;
@@ -420,7 +416,6 @@ int readServiceInfo(char * name, struct service * service, int honorHide) {
 		char *t;
 		int numdeps = 0;
 		
-		serv.kPriority = -1;
 		start+=14;
 		while (1) {
 			while (*start && isspace(*start) && start < end) start++;
